package com.ebelter.sdksdemo;


import android.bluetooth.BluetoothDevice;
import android.content.Intent;
import android.os.Bundle;
import android.text.Editable;
import android.text.TextUtils;
import android.text.TextWatcher;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.RadioGroup;
import android.widget.TextView;
import com.ebelter.sdks.bean.scale.OfflineMeasureResult;
import com.ebelter.sdks.bean.scale.ScaleMeasureResult;
import com.ebelter.sdks.bean.scale.ScaleUserInfo;
import com.ebelter.sdks.enums.ProductStyle;
import com.ebelter.sdks.interfaces.IBlueStationListener;
import com.ebelter.sdks.interfaces.IConnectStationCallback;
import com.ebelter.sdks.interfaces.scale.AIScaleMeasureCallback;
import com.ebelter.sdks.managers.ScaleManager;
import com.ebelter.sdks.utils.LogUtils;
import com.ebelter.sdks.utils.TimeUtils;

public class ScaleActivity extends SDKBaseActivity {

    private TextView tv0;
    private TextView tv1;
    private TextView tv2;
    private TextView tv3;
    private TextView tv4;

    private TextView mustconnect_tv;


    private Button start;
    private Button stop;

    private EditText et_specified_name;
    private RadioGroup rg_ble_type;

    private ScaleManager mScaleManager;

    // 是否心率秤
    private boolean isHeartScale;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_scale);
        //-----------01
        mScaleManager = new ScaleManager(this);

        FV();
        setListeners();
        initData();
    }


    private void setListeners() {

        stop.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                stopWork();
            }
        });
        start.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                startWork();
            }
        });

        mustconnect_tv.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                selectMustConnectAddress();
            }
        });


        //-----------02
        mScaleManager.addBluetoothStationListener(mBlueStationListener);//Add a mobile phone bluetooth status listener
        mScaleManager.setConnectStationCallback(mConnectStationCallback);//Add bluetooth body fat scale connection status listener
        mScaleManager.setScaleMeasureCallback(mAIScaleMeasureCallback);//Add a measurement listening

    }

    private void selectMustConnectAddress() {
        if (mScaleManager != null && mScaleManager.isWorkFlag()) {
            mScaleManager.stopWork();//先停止工作的意思
        }
        startActivityForResult(new Intent(this, SelectBlueActivity.class), 100);
    }

    private void startWork() {


        String mustConnectAddress = mustconnect_tv.getText().toString();
        String mustConnectName = et_specified_name.getText().toString();
        // 蓝牙地址流程
        if (!TextUtils.isEmpty(mustConnectAddress)) {
            LogUtils.i(TAG,"走蓝牙地址扫描流程");
            mScaleManager.setMustConnectBlueAddress(mustConnectAddress);
        }else if (!TextUtils.isEmpty(mustConnectName)){ // 蓝牙名称流程
            LogUtils.i(TAG,"走蓝牙名称扫描流程");
            mScaleManager.setDeviceBleName(isHeartScale,mustConnectName.trim());
        }
        mScaleManager.startWork();
        //-----------05

        // mScaleManager.startWork();//The engine started working
        // mScaleManager.stopWork();//The engine stop working
    }


    //停止工作
    private void stopWork() {
        mScaleManager.stopWork();//The engine stop working

        mustconnect_tv.setText("");
        mustconnect_tv.setHint("Click Select MustConnectAddress");
        et_specified_name.setText("");
        et_specified_name.setHint("Enter bluetooth name");

    }


    private void FV() {
        tv0 = findViewById(R.id.tv0);
        tv1 = findViewById(R.id.tv1);
        tv2 = findViewById(R.id.tv2);
        tv3 = findViewById(R.id.tv3);
        tv4 = findViewById(R.id.tv4);
        mustconnect_tv = findViewById(R.id.mustconnect_tv);

        start = findViewById(R.id.start);
        stop = findViewById(R.id.stop);

        et_specified_name = findViewById(R.id.et_specified_name);
        rg_ble_type = findViewById(R.id.rg_ble_type);
    }

    private void initData() {
        String sdkInfo = "versionName="+AppUtils.getVerName(this)+"-versionCode="+AppUtils.getVersionCode(this);
        setText(tv0,"EbelterSDK info:" + sdkInfo);
        setText(tv1, "Does the phone support bluetooth:       " + (mScaleManager.isSupportBluetooth() ? "Support" : "Not Support"));
        setText(tv2, "Bluetooth status of mobile phone:       " + (mScaleManager.isBluetoothOpen() ? "Open" : "Closed"));


        //-----------03
        //Set the bluetooth address that must be connected to the bluetooth body fat scale.
        // If it is null, it will randomly scan the connected device
        mScaleManager.setMustConnectBlueAddress(null);
        mScaleManager.setDeviceBleName(isHeartScale,null);
        //-----------04  Set user information
        //Set the user information, and remember to execute once the user information changes
        ScaleUserInfo userInfo = ScaleUserInfo.getScaleUserInfo();

        //Very important note：
        // UserId has a maximum length of 14 characters and must be a character of 0123456789abcdef
        //If there are more than 14 bits, the SDK automatically intercepts the next 14 bits of string

        String userId = "0123456789abcd";
        int sex = 0;                   //0 for boys and 1 for girls
        int height = 165;              //168cm
        int roleType = 0;             //0 for ordinary people and 1 for athletes
        int age = 25;                 //30 years old
        float weight = 100f;          //50.5kg For the first time, fill in a value that is similar to your weight
        userInfo.setUserId(userId);
        userInfo.setAge(sex);
        userInfo.setHeight(height);
        userInfo.setRoleType(roleType);
        userInfo.setAge(age);
        userInfo.setWeight(weight);
        mScaleManager.updateUserInfo(userInfo);//Remember to execute this method every time the user information changes

        // 秤类型
        rg_ble_type.setOnCheckedChangeListener(new RadioGroup.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(RadioGroup group, int checkedId) {
                switch (checkedId){
                    case R.id.rb_heart_scale:
                        isHeartScale = true;
                        break;
                    case R.id.rb_normal_scale:
                        isHeartScale = false;
                        break;
                }
            }
        });

    }

    private void setText(TextView tv, String msg) {
        if (tv != null) tv.setText(msg);
    }


    private final IBlueStationListener mBlueStationListener = new IBlueStationListener() {
        @Override
        public void STATE_OFF() {
            setText(tv2, "Bluetooth status of mobile phone:     Closed");
        }

        @Override
        public void STATE_TURNING_OFF() {
            setText(tv2, "Bluetooth status of mobile phone:     Closing...");
        }

        @Override
        public void STATE_ON() {
            setText(tv2, "Bluetooth status of mobile phone:     Open");
        }

        @Override
        public void STATE_TURNING_ON() {
            setText(tv2, "Bluetooth status of mobile phone:     Opening");
        }
    };


    private final IConnectStationCallback mConnectStationCallback = new IConnectStationCallback() {
        @Override
        public void onConnected(ProductStyle productStyle, BluetoothDevice device) {
            addTv4Str("-----onConnected-----" + device.getName() + "--ScaleAddress=" + device.getAddress());
            setText(tv3, "Body fat scale connection status:     Connected" + "\n ScaleName = " + device.getName() + "\nScaleAddress=" + device.getAddress());
        }

        @Override
        public void onConnecting(ProductStyle productStyle, BluetoothDevice device) {
            addTv4Str("-----onConnecting-----" + device.getName() + "--ScaleAddress=" + device.getAddress());
            setText(tv3, "Body fat scale connection status:     Connecting " + "\n ScaleName = " + device.getName() + "--ScaleAddress=" + device.getAddress());
        }

        @Override
        public void onDisConnected(ProductStyle productStyle) {
            addTv4Str("-----onDisConnected-----");
            setText(tv3, "Body fat scale connection status:     DisConnected");
        }
    };

    private final AIScaleMeasureCallback mAIScaleMeasureCallback = new AIScaleMeasureCallback() {
        @Override
        public void onScaleWake() {
            addTv4Str("-----onScaleWake-----Body fat scale wake up");
        }

        @Override
        public void onScaleSleep() {
            addTv4Str("-----onScaleSleep-----Body fat scales off screen");

            //Get the user history data at screen time
     /*       ScaleUserInfo userInfo = ScaleUserInfo.getScaleUserInfo();
            requestOffMesureData(userInfo.getUserId(), userInfo.getHeight(), userInfo.getSex(), userInfo.getAge(), userInfo.getRoleType());*/

        }

        @Override
        public void onReceiveMeasureResult(ScaleMeasureResult result) {


            //接收到测量结果先根据体重判断跟当前使用用户是不是相差2kg，如果相差2kg以内就直接执行下面代码块A1-A2,
            // 如果相差大于2kg应该弹框提示用户此条数据是不是他本人的 如果不是应该把这条数据屏蔽掉 如果是也应该执行下面代码块A1-A2,
            //-------------------------------------------------代码块A1
            if (mScaleManager!=null){
                mScaleManager.updateScaleUserInfo(result.weight,(int) result.getResistance());//这句话的意思是告诉秤这体重和阻抗确定是他的，它底层会做历史记录好判断
            }
            //-------------------------------------------------代码块A2


            StringBuffer sb = new StringBuffer();
            sb.append("IsOnlyWeightData ");
            sb.append(result.isOnlyWeightData);
            sb.append("、");
            sb.append("measureTime ");
            sb.append(result.measureTime);
            sb.append("、");
            sb.append("userId ");
            sb.append(result.userId);
            sb.append("、");
            sb.append("age ");
            sb.append(result.age);
            sb.append("、");
            sb.append("sex ");
            sb.append(result.sex);
            sb.append("、");
            sb.append("height ");
            sb.append(result.height);
            sb.append("、");
            sb.append("roleType ");
            sb.append(result.roleType);
            sb.append("、");
            sb.append("weight ");
            sb.append(result.weight);
            sb.append("、");
            sb.append("bmi ");
            sb.append(result.bmi);
            sb.append("、");
            sb.append("fat ");
            sb.append(result.fat);
            sb.append("、");
            sb.append("waterRate ");
            sb.append(result.waterRate);
            sb.append("、");
            sb.append("bmr ");
            sb.append(result.bmr);
            sb.append("、");
            sb.append("visceralFat ");
            sb.append(result.visceralFat);
            sb.append("、");
            sb.append("muscleVolume ");
            sb.append(result.muscleVolume);
            sb.append("、");
            sb.append("skeletalMuscle ");
            sb.append(result.skeletalMuscle);
            sb.append("、");
            sb.append("Bonemineralcontent ");
            sb.append(result.Bonemineralcontent);
            sb.append("、");
            sb.append("protein ");
            sb.append(result.protein);
            sb.append("、");
            sb.append("bodyScore ");
            sb.append(result.bodyScore);
            sb.append("、");
            sb.append("bodyAge ");
            sb.append(result.bodyAge);
            sb.append("、");
            sb.append("heartRate ");
            sb.append(result.heartRate);
            sb.append("、");
            sb.append("resistance ");
            sb.append(result.resistance);
            sb.append("、");
            sb.append("weightUnit ");
            sb.append(result.weightUnit);
            sb.append("、");
            sb.append("fatUnit ");
            sb.append(result.fatUnit);

            addTv4Str("测量结果=" + sb.toString());
        }

        @Override
        public void onReceivedynamicMeasureResult(ScaleMeasureResult result) {
            addTv4Str("----动态测量---onReceivedynamicMeasureResult-result=" + result);
        }


        @Override
        public void onWeightOverLoad() {
            addTv4Str("-----onWeightOverLoad-----Body fat scale overweight warning");
        }

        @Override
        public void onReceiveHistoryRecord(OfflineMeasureResult result) {
            //注意Body Fat-B16的秤没有离线数据  这个方法可以不用复写
            addTv4Str("---离线数据--onReceiveHistoryRecord-result = " + result);
            addTv4Str("-----onReceiveHistoryRecord-----Body fat scales receive historical data");

        }



        @Override
        public void onHistoryDownloadDone() {
            addTv4Str("---离线数据--onHistoryDownloadDone");
        }


        @Override
        public void onLowPower() {
            addTv4Str("-----onLowPower-----Low battery indicator on body fat scale");
        }

        @Override
        public void setUserInfoSuccess() {
            addTv4Str("-----setUserInfoSuccess-----User information set successfully");
        }

        @Override
        public void receiveTime(long time) {
            addTv4Str("-----receiveTime-----The time of receipt of the scale.---time = " + TimeUtils.formatTime1(time));
        }
    };

    private void addTv4Str(String addmsg) {
        String str;
        if (tv4 != null) {
            str = tv4.getText().toString();
            if (str.length() > 5000) {
                str = str.substring(0, 5000);
            }
            str = TimeUtils.getCurrentTime1() + "  " + addmsg + "\n\n" + str;
            tv4.setText(str);
        }
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        if (mScaleManager != null) {
            mScaleManager.removeBluetoothStationListener(mBlueStationListener);
            mScaleManager.exit();
            mScaleManager = null;
        }
    }

    //Request user information
    public void getHistoryData(View view) {
        ScaleUserInfo userInfo = ScaleUserInfo.getScaleUserInfo();
        requestOffMesureData(userInfo.getUserId(), userInfo.getHeight(), userInfo.getSex(), userInfo.getAge(), userInfo.getRoleType());
    }

    public void requestOffMesureData(String userId, int height, int sex, int age, int roleType) {
        if (mScaleManager != null && mScaleManager.isConnected()) {
            mScaleManager.requestOffMesureData(userId, height, sex, age, roleType);
        }
    }


    //Delete all user information
    public void deleteAllInfo(View view) {
        if (mScaleManager != null && mScaleManager.isConnected()) {
            mScaleManager.deleteAllUserInfo();
        }
    }
    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        if (requestCode == 100 && resultCode == 101) {
            String mustConnectAddress = data.getStringExtra(SelectBlueActivity.ADDRESS);
            if (mustconnect_tv != null) {
                mustconnect_tv.setText(mustConnectAddress);
            }
        }
    }


    public void unit1(View view) {
        if (!mScaleManager.isConnected()){
            ToastUitl.show("请先连接设备");
            return;
        }
        mScaleManager.setUnit(1);  //01:KG
    }

    public void unit2(View view) {
        if (!mScaleManager.isConnected()){
            ToastUitl.show("请先连接设备");
            return;
        }
        mScaleManager.setUnit(2);//02:LB
    }

    public void unit3(View view) {
        if (!mScaleManager.isConnected()){
            ToastUitl.show("请先连接设备");
            return;
        }
        mScaleManager.setUnit(4);    //04:斤
    }
}
