package com.ebelter.sdksdemo.utils_permission;

import android.app.Activity;
import android.content.Intent;
import android.support.annotation.NonNull;

import com.ebelter.sdksdemo.utils_permission.per_interface.PermissionInterface;


/**
 * Created by bao on 2019/3/29.
 */

public class PermissionHelper {

    private static final String TAG = "PermissionHelper";

    public static final int NOT_NOTICE_CODE = 9901;
    public static final int LOCATION_CODE = 9902;

    PermissionUtil permissionUtil = new PermissionUtil();


    private Activity mActivity;
    private PermissionInterface mPermissionInterface;
    private String[] deniedPermissions;
    // 是否正在申请权限
    private boolean isRequsrPermission;

    public PermissionHelper(Activity activity, PermissionInterface permissionInterface) {
        mActivity = activity;
        mPermissionInterface = permissionInterface;
    }

    /**
     * 开始请求权限。
     * 方法内部已经对Android M 或以上版本进行了判断，外部使用不再需要重复判断。
     * 如果设备还不是M或以上版本，则也会回调到requestPermissionsSuccess方法。
     */
    public void requestPermissions() {
        if (mActivity == null) {
            return;
        }
        if (isRequsrPermission) {
            return;
        }
        deniedPermissions = permissionUtil.getDeniedPermissions(mActivity, mPermissionInterface.getPermissions());
        if (deniedPermissions != null && deniedPermissions.length > 0) {
            isRequsrPermission = true;
            permissionUtil.requestPermissions(mActivity, deniedPermissions, mPermissionInterface.getPermissionsRequestCode());
        } else {
            isRequsrPermission = false;
            mPermissionInterface.requestPermissionsSuccess();
        }
    }

    /**
     * 在Activity中的onRequestPermissionsResult中调用
     *
     * @param requestCode
     * @param permissions
     * @param grantResults
     * @return true 代表对该requestCode感兴趣，并已经处理掉了。false 对该requestCode不感兴趣，不处理。
     */
    public boolean requestPermissionsResult(int requestCode, @NonNull String[] permissions, @NonNull int[] grantResults) {
        try {
            if (requestCode == mPermissionInterface.getPermissionsRequestCode()
                    && permissions != null && grantResults != null && mPermissionInterface != null && mActivity != null) {
                boolean isHavePermission = false;  // 是否全部权限已授权
                for (String permission : permissions) {
                    isHavePermission = permissionUtil.hasPermission(mActivity, permission);
                    if (!isHavePermission) {
                        break;
                    }
                }
                if (isHavePermission) {
                    // 已全部授权
                    isRequsrPermission = false;
                    mPermissionInterface.requestPermissionsSuccess();
                } else {
                    // 权限有缺失
                    isRequsrPermission = false;
                    mPermissionInterface.requestNoPermissionsFail();
                }
                return true;
            }
        } catch (Exception e) {

        }
        return false;
    }

    /**
     * 在Activity中的onActivityResult中调用
     *
     * @param requestCode
     * @param resultCode
     * @param data
     */
    public void onActivityResult(int requestCode, int resultCode, Intent data) {
        if (requestCode == PermissionHelper.NOT_NOTICE_CODE) {
            if (deniedPermissions != null && deniedPermissions.length > 0) {
                boolean isHavePermission = false;
                for (String permission : deniedPermissions) {
                    isHavePermission = permissionUtil.hasPermission(mActivity, permission);
                    if (!isHavePermission) {
                        break;
                    }
                }
                if (isHavePermission) {
                    // 已全部授权
                    isRequsrPermission = false;
                    mPermissionInterface.requestPermissionsSuccess();
                } else {
                    // 权限有缺失
                    isRequsrPermission = false;
                    mPermissionInterface.requestNoPermissionsFail();
                }
            } else {
                // 权限有缺失
                isRequsrPermission = false;
                mPermissionInterface.requestPermissionsFail();
            }
        }
    }
}
